@@ -24,9 +24,9 @@
 #define OKTETA_BOOKMARKLIST_H
 
 // lib
-#include "bookmark.h"
+#include <okteta/bookmark.h>
 // Qt
-#include <QtCore/QLinkedList>
+#include <QLinkedList>
 
 template <class T> class QList;
 
