@@ -23,9 +23,9 @@
 #include "charsetconversionjob.h"
 
 // Okteta core
-#include <abstractbytearraymodel.h>
-#include <charcodec.h>
-#include <character.h>
+#include <okteta/abstractbytearraymodel.h>
+#include <okteta/charcodec.h>
+#include <okteta/character.h>
 // Qt
 #include <QApplication>
 
