@@ -23,10 +23,10 @@
 #include "abstractmodelselection.h"
 
 
-namespace Kasten2
+namespace Kasten
 {
 
-class AbstractModelSelection::Private
+class Q_DECL_HIDDEN AbstractModelSelection::Private
 {
 };
 
