@@ -23,11 +23,11 @@
 #include "viewareabox.h"
 
 // Qt
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QShortcut>
+#include <QVBoxLayout>
+#include <QShortcut>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 ViewAreaBox::ViewAreaBox( QWidget* centralWidget, QWidget* parent )
